@@ -7,9 +7,14 @@ function(behavior,phaseX){
    writeLines("Use the CDC test if any phase is autocorrelated.")
    writeLines("If no autocorrelation exists in any phase, but a trend exists,") 
    writeLines("use the CDC, regabove, or regbelow test.")
-   c<-readline("(c)ontinue or (e)exit and press return (c or e) ")
+   c<-readline("(c)ontinue or (e)xit and press return (c or e) ")
    if (c=="c"|c=="C") {
    writeLines(" ")
+     DV<-( paste(substitute(behavior)) )
+     
+     l1<-c("One-way ANOVA for behavior",'"',DV,'"')
+     cat(sprintf(l1),"\n")
+     writeLines(" ")
   behavior <-na.omit(behavior)
   phase<-na.omit(phaseX)
  phase <- as.character(phase[phase!=""])
@@ -23,7 +28,8 @@ function(behavior,phaseX){
   writeLines("-----------------------------------")
   writeLines(" ")
   tukeyx<-TukeyHSD(aovx)
-  graphics.off()
+  #graphics.off()
+  layout(rbind(1,2), heights=c(6,1))
   plot(tukeyx)
   print(tukeyx)
   bartest<-bartlett.test(behavior~phase)
