@@ -1,9 +1,12 @@
 ABbinomial <-
 function(phaseX,v1,v2,successA,successB){
  options (scipen=999)
- 
-  l1<-c("Proportion Frequency/Binomial Test comparing phases", v1,"and",v2,":")
-  writeLines(" ")
+  DV<-( paste(substitute(phaseX)) )
+  DV<-substring(DV, 2)
+  
+  #l1<-c("Proportion Frequency/Binomial Test comparing phases", v1,"and",v2,":")
+  l1<-c("Proportion Frequency/Binomial Test comparing phases", v1,"and",v2,"for",'"',DV,'"',"behavior")
+   writeLines(" ")
   cat(sprintf(l1),"\n")
   
    t1<-table(phaseX)
