@@ -44,7 +44,11 @@ writeLines(" ")
   
  #layout(rbind(1,2), heights=c(4,1))
  layout(rbind(1,2), heights=c(6,1))
-  barplot(Means,ylab="mean",names.arg=c(v1,v2))
+ yt<-c("mean",DV)
+ 
+ 
+  barplot(Means,ylab=yt,names.arg=c(v1,v2),xlab="phase",main="Difference of Means")
+ 
   if (vartestp>.05) { 
   note1<-c("Note: Your variances are equal (F test to compare two variances p-value is greater than 0.05) between phases",v1, "and", v2,".","Use the Two Sample t-test")
   cat(sprintf(note1),"\n")
