@@ -15,13 +15,18 @@ function(behavior,phaseX,v1){
   yA<-regA$coefficients[1]
   BetaA<-regA$coefficient[2]
   
-
-  layout(rbind(1,2), heights=c(6,1))
-  #par(mar = rep(2, 4))
-  plot(x1, A,lwd=2,type="o",col="red", xlab="time", ylab="behavior", bty='L',main=v1 )
-  abline(c(yA,BetaA),col='Blue',lty="dashed")
-  writeLines(" ")
   DV<-( paste(substitute(behavior)) )
+ 
+   layout(rbind(1,2), heights=c(6,1))
+  
+  plot(x1, A,lwd=2,type="o",col="red", xlab="time", ylab=c(DV,"behavior"), bty='L',main=c(v1,"Phase" ))
+  abline(c(yA,BetaA),col="blue",lty="dashed")
+  writeLines(" ")
+  par(mar=c(.5, .5, .5, .5))
+  plot.new()
+  legend("center", c("behavior","regression line"), col = c("red","blue"),lty =c ("solid","dashed"), lwd = 1,ncol=2,bty ="o",cex=.8)  
+  par(mar = c(5.1, 4.1, 4.1, 2.1))
+  layout(rbind(1,2), heights=c(6,1))
 
    l1<-c("Regression for behavior",'"',DV,'"',"in the", v1, "phase")
   
