@@ -53,15 +53,15 @@ function(behavior,phaseX,v1,bandX,ABxlab,ABylab, ABmain){
   abline(h=Uband,col="blue")
   abline(h=Lband,col="orange")
   
-  # par(mar=c(1, 1, 1, 1))
-  # plot.new()
-  #legend("center", c("behavior","Uband","mean","Lband"), col = c("red","blue", "green","orange"), lwd = 1,ncol=4,bty ="n")
-  
+ 
   puband<-c("Uband=",Uband)
   pmean<-c("mean=",round(bmean,2))
   plband<-c("Lband=",Lband)
-  print(puband)
-  print(pmean)
-  print(plband)
+  writeLines(" ")
+  tprint<-c("Key:",puband,pmean,plband)
+  cat(sprintf(tprint),"\n")
+  ab<-NULL
+  
+  ab<<-recordPlot()
   
 }
