@@ -1,6 +1,6 @@
 PNDbelow <-
 function(behavior,phaseX,v1,v2){
-  
+  DV<-( paste(substitute(behavior)) )
   t1<-table(phaseX)
   tmaxA<-t1[names(t1)==v1]
   startA<-match(v1,phaseX)
@@ -46,7 +46,7 @@ function(behavior,phaseX,v1,v2){
   
   numx<-sum(!is.na(behavior))+3
   
-  DV<-( paste(substitute(behavior)) )
+  
   
   l1<-c("PND below for behavior",'"',DV,'"')
   writeLines(" ")
@@ -64,7 +64,7 @@ function(behavior,phaseX,v1,v2){
   #graphics.off()
   layout(rbind(1,2), heights=c(4,1))
   
-  plot(iv,cdcl, ylim=c(0,max),lwd=2,type="o",col="red",bty="l", xlab="time", ylab="behavior", main="PND" )
+  plot(iv,cdcl, ylim=c(0,max),lwd=2,type="o",col="red",bty="l", xlab="time", ylab=c(DV,"behavior"), main="PND Below" )
   segments(y0=minA,x0=vx,x1=endB,lwd=3)
   
  
