@@ -18,8 +18,11 @@ function(behavior,phaseX,v,l){
   endA<-tmaxA+startA-1
   A<-behavior[startA:endA]
   trimmean=mean(A,trim=.1,na.rm=T)
-  trm<-c("10% Trim Mean=",round(trimmean,3))
-  print(trm)
+  trm<-c("10 percent Trim Mean=",round(trimmean,3))
+  #print(trm)
+  writeLines(" ")
+  cat(sprintf(trm),"\n") 
+  writeLines(" ")
   #l<-locator(1)
   mlin<-l+mlin
   segments(x0=l,x1=mlin,y0=trimmean,col="red",lty=2,lwd=3)
