@@ -7,7 +7,7 @@ metareg <-
     print(summary(m0))
    print(confint(m0))
     
-    plot.new
+   layout(rbind(1,2), heights=c(6,1))
     forest(m0)
     title(main="Forest Graph of Effect Sizes")
     options(warn=-0)
